<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Plugin Name: Cashvault Escrow WooCommerce 
 * Plugin URI: https://wordpress.org/plugins/cashvault-woocommerce/
 * Description: Cashvault Escrow Plugin for Woocommerce, it allows merchants to process payment through an escrow holding funds for payment from customers for merchants till delivery time. 
 * Version: 1.2.1
 * Author: Cashvault
 * Author URI: https://cashvaultng.com
 * Copyright:  2018.
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain: cashvault-escrow-woocommerce
 * Domain Path: /languages
 * WC tested up to: 3.4
 * WC requires at least: 2.6
 */
/**
 * Copyright (c) 2018 Safeonline
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */


global $wpdb;
$table_name = $wpdb->prefix.'cash_vaultng';

//$result = $wpdb->get_results('SELECT * FROM ' . $wpdb->prefix . 'posts LIMIT 10');

add_action( 'plugins_loaded', 'init_cash_vault_gateway_class' );
register_activation_hook( __FILE__, 'cash_vault_gateway_plugin_activation' );

function cash_vault_gateway_plugin_activation() {
	if ( class_exists( 'WooCommerce' ) ) {
		
	} else {
		deactivate_plugins( basename( __FILE__ ) );
		wp_die(
			'<p>' .
			sprintf(
				__( 'This plugin can not be activated because WooCommerce is not installed.', 'cash_vault_gateway' ),
				$php
			)
			. '</p> <a href="' . admin_url( 'plugins.php' ) . '">' . __( 'go back', 'cash_vault_gateway' ) . '</a>'
);
	}
	
}

function init_cash_vault_gateway_class() {

if ( class_exists( 'WooCommerce' ) ) {
    class WC_Gateway_Cash_Vault extends WC_Payment_Gateway {

	/**
	 * Constructor for the gateway.
	 */
	public function __construct() {

		$banklist1 = "ABP,Access Bank,044
		ECO,Ecobank,050
		FBP,Fidelity Bank,070
		FBN,First Bank,011
		FCMB,First City Monument Bank,214
		GTB,Guaranty Trust Bank,058
		HBP,Heritage Bank,030
		JAIZ,Jaiz Bank,301
		KSB,Keystone Bank,082
		UMB,Providus Bank,101
		SKYE,Polaris Bank,076
		STANBIC,Stanbic IBTC,039
		SBP,Sterling Bank,232
		SUN,Suntrust Bank,100
		UBN,Union Bank,032
		UBA,United Bank For Africa,033
		UNITY,Unity Bank,215
		WEMA,Wema Bank,035
		ZIB,Zenith Bank,057
";
		$banklist2 = explode("\n", $banklist1);
		foreach ($banklist2 as $key => $val) {
			if ($val != "") {
				$bank1 = explode(",", $val);
				$this->banklist[$bank1[2]] = $bank1[1];
			}
		}
		$this->id                 = 'cash_vault';
		$this->icon               = plugin_dir_url( __FILE__ ) . '/assets/img/cf700f0-CV-Buttom.png';
		$this->has_fields         = true;
		$this->method_title       = __( 'Cashvault', 'woocommerce' );
		$this->method_description = __( 'Allows payments by Cashvault.', 'woocommerce' );

		// Load the settings.
		$this->init_form_fields();
		$this->init_settings();

		// Define user set variables
		$this->title        = $this->get_option( 'title' );
		$this->description  = $this->get_option( 'description' );
		$this->instructions = $this->get_option( 'instructions' );
		$this->enabled_live = $this->get_option( 'enabled_live' );
		$this->api_merchant_id = $this->get_option( 'api_merchant_id' );
		$this->api_client_id = $this->get_option( 'api_client_id' );
		$this->api_client_secret_key = $this->get_option( 'api_client_secret_key' );

		$this->test_api_merchant_id = $this->get_option( 'test_api_merchant_id' );
		$this->test_api_client_id = $this->get_option( 'test_api_client_id' );
		$this->test_api_client_secret_key = $this->get_option( 'test_api_client_secret_key' );

		$this->merchant_state = $this->get_option( 'merchant_state' );
		$this->in_state_delivery_duration = $this->get_option( 'in_state_delivery_duration' );
		$this->outof_state_delivery_duration = $this->get_option( 'outof_state_delivery_duration' );
		$this->merchant_mobile = $this->get_option( 'merchant_mobile' );
		$this->merchant_email = $this->get_option( 'merchant_email' );
		$this->confirm_cancellation_fee = $this->get_option( 'confirm_cancellation_fee' );
		$this->cancellation_threshold = $this->get_option( 'cancellation_threshold' );

		$this->free_delivery = $this->get_option( 'free_delivery' );
		$this->free_delivery_threshold = $this->get_option( 'free_delivery_threshold' );
		
		$this->split = $this->get_option( 'split' );
		$this->split_merchant_bank = $this->get_option( 'split_merchant_bank' );
		$this->split_merchant_account = $this->get_option( 'split_merchant_account' );
		$this->split_courier = $this->get_option( 'split_courier' );

		// CV account fields shown on the thanks page and in emails
		$this->courier_details = get_option( 'woocommerce_cash_vault_couriers',
			array(
				array(
					'delivery_type'   => $this->get_option( 'delivery_type' ),
					'courier_name'   => $this->get_option( 'courier_name' ),
					'notification_email' => $this->get_option( 'notification_email' ),
					'notification_mobile'      => $this->get_option( 'notification_mobile' ),
					'delivery_fee'      => $this->get_option( 'delivery_fee' ),
					'bank'      => $this->get_option( 'bank' ),
					'account_number'           => $this->get_option( 'account_number' ),
					'delivery_duration'            => $this->get_option( 'delivery_duration' ),
				),
			)
		);

		$this->delivery_type = '';
		add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );

		add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'save_courier_details' ) );
		//add_action( 'woocommerce_review_order_after_submit', 'action_woocommerce_cash_vault_review_order_after_submit' );
		add_action( 'woocommerce_api_'. strtolower( get_class($this) ), array( $this, 'callback_handler' ) );
		add_action( 'init', array( $this, 'cash_vault_load_ajax' ) );
            if ( !is_user_logged_in() ){
                add_action( 'wp_ajax_nopriv_cash_vault_update_order_review', array( $this, 'cash_vault_update_order_review' ) );
            } else{
                add_action( 'wp_ajax_cash_vault_update_order_review',        array( $this, 'cash_vault_update_order_review' ) );
            }
		add_action( 'woocommerce_cart_calculate_fees', array( $this, 'calculate_totals' ));
		add_filter( 'woocommerce_gateway_icon', array($this, 'cash_vault_gateway_icon'), 10, 2);

	}

	function cash_vault_gateway_icon( $icon, $id ) {
	    if ( $id === 'cash_vault' ) {
        	return '<img src="' . plugin_dir_url( __FILE__ ) . '/assets/img/cf700f0-CV-Buttom.png' .'" alt="Pay With Cashvault" />'; 
	    } else {
        	return $icon;
	    }
	}

	function calculate_totals($totals) {
		//echo $this->delivery_type;
		//echo "<BR>";
		global $woocommerce;
		$delivery_type = WC()->session->get( 'cash_vault_delivery_type' );
		if ($delivery_type != "") {
			foreach ( $this->courier_details as $courier ) {
				if ($courier['delivery_type'] == $delivery_type) {
					if (($this->free_delivery == 'yes' ) && ($woocommerce->cart->cart_contents_total > $this->free_delivery_threshold)) {
						$woocommerce->cart->add_fee(__("Delivery Fee"),0,false);
					} else {
						$woocommerce->cart->add_fee(__("Delivery Fee"),$courier['delivery_fee'],false);
					}
				}
			}
		}
		return $totals;
	}


	public function cash_vault_load_ajax() {
            if ( !is_user_logged_in() ){
                add_action( 'wp_ajax_nopriv_cash_vault_update_order_review', array( $this, 'cash_vault_update_order_review' ) );
            } else{
                add_action( 'wp_ajax_cash_vault_update_order_review',        array( $this, 'cash_vault_update_order_review' ) );
            }
	}
	
	public function init_form_fields() {

wc_enqueue_js( "
	jQuery( function( $ ) {
		var cash_vault_mark_fields      = '#woocommerce_cash_vault_title, #woocommerce_cash_vault_description';
		var cash_vault_live_fields      = '#woocommerce_cash_vault_api_merchant_id, #woocommerce_cash_vault_api_client_id, #woocommerce_cash_vault_api_client_secret_key';
		var cash_vault_test_fields   = '#woocommerce_cash_vault_test_api_merchant_id, #woocommerce_cash_vault_test_api_client_id, #woocommerce_cash_vault_test_api_client_secret_key';
		var cash_vault_split_fields      = '#woocommerce_cash_vault_split_merchant_bank, #woocommerce_cash_vault_split_merchant_account, #woocommerce_cash_vault_split_courier';

		var enable_toggle         = $( 'a.cash_vault_toggle_settings' ).length > 0;
		var enable_test_toggle = $( 'a.cash_vault_toggle_test_settings' ).length > 0;

		$( '#mainform' ).submit(function( event ) {
			var numericcheck = /^[0-9]+$/;
			// check mobile numbers are 11 digits long
			var elements = $('[name^=cash_vault_notification_mobile]');
			var elements1 = $('[name^=cash_vault_delivery_type]');
			elements.each(function( index, item ) {
			  if (elements1[index].value !== \"\") {
				  if (!numericcheck.test(item.value)) {
					alert('Error Mobile Number Must be of numeric');
					item.focus();
					event.preventDefault();
					return false;
				  } else if (item.value.length != 11) {
					alert('Error Mobile Number Must be of 11 digits long');
					item.focus();
					event.preventDefault();
					return false;
				  } 
			   }
			});

			var elements = $('[name^=woocommerce_cash_vault_merchant_mobile]');
			elements.each(function( index, item ) {
			  if (!numericcheck.test(item.value)) {
				alert('Error Mobile Number Must be of numeric');
				item.focus();
				event.preventDefault();
				return false;
			  } else if (item.value.length != 11) {
				alert('Error Mobile Number Must be of 11 digits long');
				item.focus();
				event.preventDefault();
				return false;
			  } 
			});

			var elements = $('[name^=cash_vault_account_number]');
			elements.each(function( index, item ) {
			  if (!numericcheck.test(item.value) && item.value !='') {
				alert('Error Account Number Must be of numeric ' + index);
				item.focus();
				event.preventDefault();
				return false;
			  } else if (item.value.length != 10 && item.value !='') {
				alert('Error Account Number Must be of 10 digits long ' + index);
				item.focus();
				event.preventDefault();
				return false;
			  } 
			});

			if ($( '#woocommerce_cash_vault_split' ).is( ':checked' )) {
				var elements = $('[name^=woocommerce_cash_vault_split_merchant_account]');
				elements.each(function( index, item ) {
				if (!numericcheck.test(item.value)  && item.value !='') {
					alert('Error Merchant Account Number Must be of numeric ' + index);
					item.focus();
					event.preventDefault();
					return false;
				  }
				  if (item.value.length != 10  && item.value !='') {
					alert('Error Merchant Account Number Must be of 10 digits long ' + index);
					item.focus();
					event.preventDefault();
					return false;
				  } 
				});
			} 
		  //event.preventDefault();
		});

		$( '#woocommerce_cash_vault_environment' ).change(function(){
			$( cash_vault_test_fields + ',' + cash_vault_live_fields ).closest( 'tr' ).hide();

			if ( 'live' === $( this ).val() ) {
				$( '#woocommerce_cash_vault_api_credentials, #woocommerce_cash_vault_api_credentials + p' ).show();
				$( '#woocommerce_cash_vault_test_api_credentials, #woocommerce_cash_vault_test_api_credentials + p' ).hide();

				if ( ! enable_toggle ) {
					$( cash_vault_live_fields ).closest( 'tr' ).show();
				}
			} else {
				$( '#woocommerce_cash_vault_api_credentials, #woocommerce_cash_vault_api_credentials + p' ).hide();
				$( '#woocommerce_cash_vault_test_api_credentials, #woocommerce_cash_vault_test_api_credentials + p' ).show();

				if ( ! enable_test_toggle ) {
					$( cash_vault_test_fields ).closest( 'tr' ).show();
				}
			}
		}).change();

		$( '#woocommerce_cash_vault_enabled' ).change(function(){
			if ( $( this ).is( ':checked' ) ) {
				$( cash_vault_mark_fields ).closest( 'tr' ).show();
			} else {
				$( cash_vault_mark_fields ).closest( 'tr' ).hide();
			}
		}).change();

		$( '#woocommerce_cash_vault_split' ).change(function(){
			if ( $( this ).is( ':checked' ) ) {
				$( cash_vault_split_fields ).closest( 'tr' ).show();
			} else {
				$( cash_vault_split_fields ).closest( 'tr' ).hide();
			}
		}).change();


		$( '#woocommerce_cash_vault_paymentaction' ).change(function(){
			if ( 'sale' === $( this ).val() ) {
				$( '#woocommerce_cash_vault_instant_payments' ).closest( 'tr' ).show();
			} else {
				$( '#woocommerce_cash_vault_instant_payments' ).closest( 'tr' ).hide();
			}
		}).change();

		if ( enable_toggle ) {
			$( document ).on( 'click', '.cash_vault_toggle_settings', function( e ) {
				$( cash_vault_live_fields ).closest( 'tr' ).toggle( 'fast' );
				e.preventDefault();
			} );
		}
		if ( enable_test_toggle ) {
			$( document ).on( 'click', '.cash_vault_toggle_test_settings', function( e ) {
				$( cash_vaulttest_fields ).closest( 'tr' ).toggle( 'fast' );
				e.preventDefault();
			} );
		}
	});
" );

		$countries = new WC_Countries();
		$states = $countries->get_states("NG");
		$st1 = array();
		foreach ($states as $key => $val) {
			$st1[$key] = $val;
		}
		foreach ($this->banklist as $key => $value) {
			$bl[$key] = __( $value, 'woocommerce-gateway-cash-vault' );
		}

		$this->form_fields = array(
		'enabled' => array(
        		'title' => __( 'Enable/Disable', 'woocommerce-gateway-cash-vault' ),
		        'type' => 'checkbox',
        		'label' => __( 'Enable Cashvault', 'woocommerce-gateway-cash-vault' ),
	        	'default' => 'yes'
		),
		'title' => array(
        		'title' => __( 'Title', 'woocommerce-gateway-cash-vault' ),
		        'type' => 'text',
        		'description' => __( 'This controls the title which the user sees during checkout.', 'woocommerce-gateway-cash-vault' ),
	        	'default' => __( '', 'woocommerce-gateway-cash-vault' ),
	        	'desc_tip'      => true,
		),
		'description' => array(
        		'title' => __( 'Customer Message', 'woocommerce-gateway-cash-vault' ),
	        	'type' => 'textarea',
	        	'default' => ''
		),
		'enabled_live' => array(
			'title'   => __( 'Enable/Disable Live Environment', 'woocommerce-gateway-cash-vault' ),
			'type'    => 'checkbox',
			'label'   => __( 'Enable Live Environment', 'woocommerce-gateway-cash-vault' ),
			'description' => __( 'This enables Live Cashvault Environment', 'woocommerce-gateway-cash-vault' ),
			'desc_tip'    => true,
			'default'     => 'no',
		),
		'environment' => array(
			'title'       => __( 'Environment', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'select',
			'class'       => 'wc-enhanced-select',
			'description' => __( 'This setting specifies whether you will process live transactions, or whether you will process simulated transactions using Cashvault test.', 'woocommerce-gateway-cash-vault' ),
			'default'     => 'live',
			'desc_tip'    => true,
			'options'     => array(
				'live'    => __( 'Live', 'woocommerce-gateway-cash-vault' ),
				'test' => __( 'Test', 'woocommerce-gateway-cash-vault' ),
			),
		),
		'api_credentials' => array(
			'title'       => __( 'API Credentials', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'title',
			'description' => $api_creds_text,
		),
		'api_merchant_id' => array(
			'title'       => __( 'Live API Merchant ID', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'text',
			'description' => __( 'Get your API credentials from Cashvault.', 'woocommerce-gateway-cash-vault' ),
			'default'     => '',
			'desc_tip'    => true,
		),
		'api_client_id' => array(
			'title'       => __( 'Live API Client ID', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'text',
			'description' => __( 'Get your API credentials from Cashvault.', 'woocommerce-gateway-cash-vault' ),
			'default'     => '',
			'desc_tip'    => true,
		),
		'api_client_secret_key' => array(
			'title'       => __( 'Live API Client Secret Key', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'text',
			'description' => __( 'Get your API credentials from Cashvault.', 'woocommerce-gateway-cash-vault' ),
			'default'     => '',
			'desc_tip'    => true,
		),
		'test_api_credentials' => array(
			'title'       => __( 'Test API Credentials', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'title',
			'description' => $test_api_creds_text,
		),
		'test_api_merchant_id' => array(
			'title'       => __( 'Test API Merchant ID', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'text',
			'description' => __( 'Get your API credentials from the dashboard.', 'woocommerce-gateway-cash-vault' ),
			'default'     => '',
			'desc_tip'    => true,
		),
		'test_api_client_id' => array(
			'title'       => __( 'Test API Client ID', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'text',
			'description' => __( 'Get your API credentials from the dashboard.', 'woocommerce-gateway-cash-vault' ),
			'default'     => '',
			'desc_tip'    => true,
		),
		'test_api_client_secret_key' => array(
			'title'       => __( 'Test API Client Secret Key', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'text',
			'description' => __( 'Get your API credentials from the dashboard.', 'woocommerce-gateway-cash-vault' ),
			'default'     => '',
			'desc_tip'    => true,
		),
		'confirm_cancellation_fee' => array(
			'title'   => __( 'Confirm Cancellation Fee', 'woocommerce-gateway-cash-vault' ),
			'type'    => 'checkbox',
			'label'   => __( 'Confirm Cancellation Fee', 'woocommerce-gateway-cash-vault' ),
			'description' => __( 'Confirm Cancellation Fee Yes or No', 'woocommerce-gateway-cash-vault' ),
			'desc_tip'    => true,
			'default'     => 'no',
		),
		'cancellation_threshold' => array(
			'title'   => __( 'Cancellation Threshold', 'woocommerce-gateway-cash-vault' ),
			'type'    => 'text',
			'label'   => __( 'Cancellation Threshold', 'woocommerce-gateway-cash-vault' ),
			'description' => __( 'Cancellation Threshold. Cancellation fee applies when order amount is less than value in this box', 'woocommerce-gateway-cash-vault' ),
			'desc_tip'    => true,
			'default'     => '',
		),
		//'with_shipping_plugin' => array(
		//	'title'       => __( 'Have Shipping Plugin', 'woocommerce-gateway-cash-vault' ),
		//	'type'        => 'title',
		//	'description' => 'Settings when shipping plugin installed',
		//),
		'merchant_state' => array(
			'title'       => __( 'Merchant State', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'select',
			'class'       => 'wc-enhanced-select',
			'description' => __( 'Select your business state of operation from where goods will be shipped from.', 'woocommerce-gateway-cash-vault' ),
			'default'     => 'Abia',
			'desc_tip'    => true,
			'options'     => $st1,
		),
		'in_state_delivery_duration' => array(
			'title'   => __( 'In State Delivery Duration (Hours)', 'woocommerce-gateway-cash-vault' ),
			'type'    => 'text',
			'label'   => __( 'In State Delivery Duration', 'woocommerce-gateway-cash-vault' ),
			'description' => __( 'In State Delivery Duration', 'woocommerce-gateway-cash-vault' ),
			'desc_tip'    => true,
			'default'     => '',
		),
		'outof_state_delivery_duration' => array(
			'title'   => __( 'Out Of State Delivery Duration (Hours)', 'woocommerce-gateway-cash-vault' ),
			'type'    => 'text',
			'label'   => __( 'Out Of State Delivery Duration', 'woocommerce-gateway-cash-vault' ),
			'description' => __( 'Out Of State Delivery Duration', 'woocommerce-gateway-cash-vault' ),
			'desc_tip'    => true,
			'default'     => '',
		),
		'merchant_mobile' => array(
			'title'   => __( 'Merchant Mobile', 'woocommerce-gateway-cash-vault' ),
			'type'    => 'text',
			'label'   => __( 'Merchant Mobile number.', 'woocommerce-gateway-cash-vault' ),
			'description' => __( 'Merchant Mobile number.', 'woocommerce-gateway-cash-vault' ),
			'desc_tip'    => true,
			'default'     => '',
		),
		'merchant_email' => array(
			'title'   => __( 'Merchant Email', 'woocommerce-gateway-cash-vault' ),
			'type'    => 'text',
			'label'   => __( 'Merchant Email.', 'woocommerce-gateway-cash-vault' ),
			'description' => __( 'Merchant Email.', 'woocommerce-gateway-cash-vault' ),
			'desc_tip'    => true,
			'default'     => '',
		),
		//'no_shipping_plugin' => array(
		//	'title'       => __( 'No Shipping plugin', 'woocommerce-gateway-cash-vault' ),
		//	'type'        => 'title',
		//	'description' => 'Settings when shipping plugin is not installed',
		//),
		//'free_delivery' => array(
		//	'title'   => __( 'Free Delivery', 'woocommerce-gateway-cash-vault' ),
		//	'type'    => 'checkbox',
		//	'label'   => __( 'Free Delivery on order amount over threshold amount', 'woocommerce-gateway-cash-vault' ),
		//	'description' => __( 'Free Delivery Yes/No', 'woocommerce-gateway-cash-vault' ),
		//	'desc_tip'    => true,
		//	'default'     => 'no',
		//),
		//'free_delivery_threshold' => array(
		//	'title'   => __( 'Free Delivery Threshold', 'woocommerce-gateway-cash-vault' ),
		//	'type'    => 'text',
		//	'label'   => __( 'Free Delivery Threshold', 'woocommerce-gateway-cash-vault' ),
		//	'description' => __( 'Free Delivery Threshold. When order amount is greater than value in this box delivery will be free', 'woocommerce-gateway-cash-vault' ),
		//	'desc_tip'    => true,
		//	'default'     => '',
		//),
		//'courier_detail' => array(
		//	'title'       => __( 'Courier Details', 'woocommerce-gateway-cash-vault' ),
		//	'type'        => 'title',
		//	'description' => $api_courier_detail_text,
		//),
		//	'courier_details' => array(
		//		'type'        => 'courier_details',			
		//	),
		'split_heading' => array(
			'title'       => __( 'Split', 'woocommerce-gateway-cash-vault' ),
			'type'        => 'title',
				'description' => $api_split_text,
		),
		'split' => array(
				'title'   => __( 'Split Yes/No', 'woocommerce-gateway-cash-vault' ),
				'type'    => 'checkbox',
				'label'   => __( 'Split yes/No', 'woocommerce-gateway-cash-vault' ),
				'description' => __( 'Split Yes or No', 'woocommerce-gateway-cash-vault' ),
				'desc_tip'    => true,
				'default'     => 'no',
		),
		'split_merchant_bank' => array(
				'title'       => __( 'Merchant Bank', 'woocommerce-gateway-cash-vault' ),
				'type'        => 'select',
				'class'       => 'wc-enhanced-select',
				'description' => __( 'Select Merchant Bank from Dropdown.', 'woocommerce-gateway-cash-vault' ),
				'default'     => 'live',
				'desc_tip'    => true,
				'options'     => $bl,
		),
		'split_merchant_account' => array(
				'title'       => __( 'Merchant Account Number', 'woocommerce-gateway-cash-vault' ),
				'type'        => 'text',
				'description' => __( 'Enter Merchant Account Number.', 'woocommerce-gateway-cash-vault' ),
				'default'     => '',
				'desc_tip'    => true,
		),
		//'split_courier' => array(
		//	'title'   => __( 'Split Courier Yes/No', 'woocommerce-gateway-cash-vault' ),
		//	'type'    => 'checkbox',
		//	'label'   => __( 'Split Courier yes/No', 'woocommerce-gateway-cash-vault' ),
		//	'description' => __( 'Split Courier Yes or No', 'woocommerce-gateway-cash-vault' ),
		//	'desc_tip'    => true,
		//	'default'     => 'no',
		//),

		);
	} // end function init_form_fields

	/**
	 * Generate account details html.
	 *
	 * @return string
	 */

	 /**public function generate_courier_details_html() {

		ob_start();

		$country 	= WC()->countries->get_base_country();
		$locale = '';

		// Get sortcode label in the $locale array and use appropriate one
		$sortcode = isset( $locale[ $country ]['sortcode']['label'] ) ? $locale[ $country ]['sortcode']['label'] : __( 'Sort code', 'woocommerce' );

		?>
		<tr valign="top">
			<th scope="row" class="titledesc"><?php _e( 'Courier details', 'woocommerce-gateway-cash-vault' ); ?>:</th>
			<td class="forminp" id="cash_vault_couriers">
				<table class="widefat wc_input_table sortable" cellspacing="0">
					<thead>
						<tr>
							<th class="sort">&nbsp;</th>
							<th><?php _e( 'Delivery Type', 'woocommerce-gateway-cash-vault' ); ?></th>
							<th><?php _e( 'Courier name', 'woocommerce-gateway-cash-vault' ); ?></th>
							<th><?php _e( 'Email Address', 'woocommerce-gateway-cash-vault' ); ?></th>
							<th><?php _e( 'Mobile Number', 'woocommerce-gateway-cash-vault' ); ?></th>
							<th><?php _e( 'Delivery Fee', 'woocommerce-gateway-cash-vault' ); ?></th>
							<th><?php _e( 'Bank', 'woocommerce-gateway-cash-vault' ); ?></th>
							<th><?php _e( 'Account Number', 'woocommerce-gateway-cash-vault' ); ?></th>
							<th><?php _e( 'Delivery Duration<BR>(hrs)', 'woocommerce-gateway-cash-vault' ); ?></th>
						</tr>
					</thead>
					<tbody class="couriers">
						<?php
						$i = -1;
						if ( $this->courier_details ) {
							foreach ( $this->courier_details as $courier ) {
								$i++;

								echo '<tr class="courier">
									<td class="sort"></td>
									<td><input type="text" value="' . esc_attr( wp_unslash( $courier['delivery_type'] ) ) . '" name="cash_vault_delivery_type[' . $i . ']" /></td>
									<td><input type="text" value="' . esc_attr( wp_unslash( $courier['courier_name'] ) ) . '" name="cash_vault_courier_name[' . $i . ']" /></td>
									<td><input type="text" value="' . esc_attr( wp_unslash($courier['notification_email'] ) ) . '" name="cash_vault_notification_email[' . $i . ']" /></td>
									<td><input type="text" value="' . esc_attr( wp_unslash( $courier['notification_mobile'] ) ) . '" name="cash_vault_notification_mobile[' . $i . ']" size="12" /></td>
									<td><input type="text" value="' . esc_attr( $courier['delivery_fee'] ) . '" name="cash_vault_delivery_fee[' . $i . ']" size="7" /></td>
									<td><select name="cash_vaultbank[' . $i . ']" style="width: 150px;">';
										foreach ($this->banklist as $key => $value) {
											$selected = '';
											if ($key == $courier['bank']) {
												$selected = "selected";
											}
											echo "<option value=\"$key\" $selected>$value</option>";
										}
									echo '</select>
									</td>
									<td><input type="text" value="' . esc_attr( $courier['account_number'] ) . '" name="cash_vaultaccount_number[' . $i . ']" size="11"/></td>
									<td><input type="text" value="' . esc_attr( $courier['delivery_duration'] ) . '" name="cash_vaultdelivery_duration[' . $i . ']" size="5"/></td>
								</tr>';
							}
						}
						?>
					</tbody>
					<tfoot>
						<tr>
							<th colspan="7"><a href="#" class="add button"><?php _e( '+ Add Courier', 'woocommerce-gateway-cash-vault' ); ?></a> <a href="#" class="remove_rows button"><?php _e( 'Remove selected courier(s)', 'woocommerce-gateway-cash-vault' ); ?></a></th>
						</tr>
					</tfoot>
				</table>
				<script type="text/javascript">
					jQuery(function() {
						jQuery('#cash_vaultcouriers').on( 'click', 'a.add', function(){

							var size = jQuery('#cash_vaultcouriers').find('tbody .courier').length;

							jQuery('<tr class="courier">\
									<td class="sort"></td>\
									<td><input type="text" name="cash_vaultdelivery_type[' + size + ']" /></td>\
									<td><input type="text" name="cash_vaultcourier_name[' + size + ']" /></td>\
									<td><input type="text" name="cash_vaultnotification_email[' + size + ']" /></td>\
									<td><input type="text" name="cash_vaultnotification_mobile[' + size + ']" /></td>\
									<td><input type="text" name="cash_vaultdelivery_fee[' + size + ']" /></td>\
									<td><select name="cash_vaultbank[' + size + ']">\
									<?php foreach ($this->banklist as $key => $value) {
											echo "<option value=\"$key\">$value</option>\\\n";
										}
									?></select></td>\
									<td><input type="text" name="cash_vaultaccount_number[' + size + ']" /></td>\
									<td><input type="text" name="cash_vaultdelivery_duration[' + size + ']" /></td>\
								</tr>').appendTo('#cash_vaultcouriers table tbody');

							return false;
						});
					});
				</script>
			</td>
		</tr>
		<?php
		return ob_get_clean();

	}*/ // end generate_courier_details_html

	/**
	 * Save account details table.
	 */

	/**public function save_courier_details() {
		$couriers = array();

		if ( isset( $_POST['cash_vaultcourier_name'] ) ) {

			$delivery_types   = array_map( 'wc_clean', sanitize_text_field($_POST['cash_vaultdelivery_type']) );
			$courier_names   = array_map( 'wc_clean', sanitize_text_field($_POST['cash_vaultcourier_name']) );
			$notification_emails = array_map( 'wc_clean', sanitize_email($_POST['cash_vaultnotification_email']) );
			$notification_mobiles      = array_map( 'wc_clean', sanitize_text_field($_POST['cash_vaultnotification_mobile']) );
			$delivery_fees      = array_map( 'wc_clean', sanitize_text_field($_POST['cash_vaultdelivery_fee']) );
			$banks           = array_map( 'wc_clean', sanitize_text_field($_POST['cash_vaultbank']) );
			$account_numbers            = array_map( 'wc_clean', sanitize_text_field($_POST['cash_vaultaccount_number']) );
			$delivery_durations           = array_map( 'wc_clean', sanitize_text_field($_POST['cash_vaultdelivery_duration']) );

			foreach ( $courier_names as $i => $name ) {
				if ( ! isset( $courier_names[ $i ] ) ) {
					continue;
				}

				$couriers[] = array(
					'delivery_type'   => $delivery_types[ $i ],
					'courier_name'   => $courier_names[ $i ],
					'notification_email' => $notification_emails[ $i ],
					'notification_mobile'      => $notification_mobiles[ $i ],
					'delivery_fee'      => $delivery_fees[ $i ],
					'bank'           => $banks[ $i ],
					'account_number'            => $account_numbers[ $i ],
					'delivery_duration'           => $delivery_durations[ $i ],
				);
			}
		}

		update_option( 'woocommerce_cash_vaultcouriers', $couriers );

	}*/

	/**
	 * Process the payment and return the result.
	 *
	 * @param int $order_id
	 * @return array
	 */

	public function process_payment( $order_id ) {
		global $woocommerce;

		if ($this->enabled_live == 'no') {
			if (($this->test_api_merchant_id == "") or ($this->test_api_client_id == "") or ($this->test_api_client_secret_key == "")) {
				$details['status'] = 'error: Cashvault API Test Credentials not set';
				update_cash_vaultdb($order_id, $details);
				wc_add_notice( "Cashvault API settings are invalid<BR>".$sql."<BR>", 'error');
				return;
			}

		} else {
			if (($this->api_merchant_id == "") or ($this->api_client_id == "") or ($this->api_client_secret_key == "")) {
				$details['status'] = 'error: Cashvault API Live Credentials not set';
				update_cash_vaultdb($order_id, $details);
				wc_add_notice( "Cashvault API settings are invalid", 'error');
				return;
			}

		}

		$order = wc_get_order( $order_id );
	
		$order_total = $order->get_total();

		$shippingplugin = false;
		if (strlen(sanitize_text_field($_POST['shipping_method'][0])) > 1) {
			$shippingplugin = true;
		}
		$currency = get_woocommerce_currency();
		if ($shippingplugin) {
			$shipping = $order->get_total_shipping();
			$shipstate = $order->shipping_state;
			$billstate = $order->billing_state;

			if ($this->merchant_state == $shipstate && $shipstate != "") {
				$delivery_duration = $this->in_state_delivery_duration;
			} elseif ($this->merchant_state == $billstate && $billstate != "") {
				$delivery_duration = $this->in_state_delivery_duration;
			} else {
				$delivery_duration = $this->outof_state_delivery_duration;
			}
			$cash_vault_post_array = [];
			$delivery_type = $this->merchant_email . "-" . $this->merchant_mobile . "-" . $shipping;
			$cash_vault_post_array['DeliveryDuration'] = $delivery_duration;
			$cash_vault_post_array['DeliveryFee'] = $shipping;
			$cash_vault_post_array['DispatchEmail'] = $this->merchant_email;
			$cash_vault_post_array['DispatchMobile'] = $this->merchant_mobile;
			$cash_vault_post_array['DispatchName'] = "WooCommerce";
			$cash_vault_post_array['OrderAmount'] = $order_total;
			$cash_vault_post_array['OrderNumber'] = 'A' . str_pad($order_id, 7, "0", STR_PAD_LEFT);

			if ($this->confirm_cancellation_fee == 'yes' && ($woocommerce->cart->cart_contents_total < $this->cancellation_threshold)) {
				$cash_vault_post_array['RefundDelivery'] = 1;
				$cash_vault_post_array['DeliveryFee'] = $shipping + 100;
			} else {
				$cash_vault_post_array['RefundDelivery'] = 0;
				$cash_vault_post_array['DeliveryFee'] = 0;
			}

			$date1 = new DateTime();
			$wat_time = new DateTimeZone('Africa/Lagos');
			$date1->setTimezone($wat_time);

			$cash_vault_post_array['ReservationDate'] = $date1->format('Y-m-d H:i:s');
			if ($this->enabled_live == 'no') {
				$cash_vault_post_array['ReservationId'] = $this->test_api_merchant_id . time();
			} else {
				$cash_vault_post_array['ReservationId'] = $this->api_merchant_id . time();;
			}
			if ($this->split == 'yes') {
				$tmp['AccountNo'] = $this->split_merchant_account;
				$tmp['CbnCode'] = $this->split_merchant_bank;
				$tmp['SplitPercentage'] = 100;
				$cash_vault_post_array['ReservationRequestSplits'][] = $tmp;
			}

			$cash_vault_post_array['ReturnUrl'] = $this->get_return_url( $order );

			//wc_add_notice(  print_r($order, true), 'error' );
			//wc_add_notice(  "tot: $order_total shipping: $shipping shippingplugin: $shippingplugin shipstate: $shipstate billstate: $billstate delivery_duration: $delivery_duration<BR>" . "<BR>" . json_encode($cash_vault_post_array) , 'error' );
			//return;	
			
		} else {
			$cash_vault_post_array = [];
			    $delivery_type = sanitize_text_field($_POST['cash_vaultdelivery_type']);
			    $dt = 0;
			    foreach ( $this->courier_details as $courier ) {
				if ($courier['delivery_type'] == $delivery_type) {
					$dt = 1;
					$cash_vault_post_array['DeliveryDuration'] = $courier['delivery_duration'];
					$cash_vault_post_array['DeliveryFee'] = $courier['delivery_fee'];
					$cash_vault_post_array['DispatchEmail'] = $courier['notification_email'];
					$cash_vault_post_array['DispatchMobile'] = $courier['notification_mobile'];
					$cash_vault_post_array['DispatchName'] = $courier['courier_name'];
					$cash_vault_post_array['OrderAmount'] = $order_total;
					$cash_vault_post_array['OrderNumber'] = 'A' . str_pad($order_id, 7, "0", STR_PAD_LEFT);
					
					if ($this->confirm_cancellation_fee == 'yes' && ($woocommerce->cart->cart_contents_total < $this->cancellation_threshold)) {
						$cash_vault_post_array['RefundDelivery'] = 1;
						$cash_vault_post_array['DeliveryFee'] = $courier['delivery_fee'] + 100;
					} else {
						$cash_vault_post_array['RefundDelivery'] = 0;
						$cash_vault_post_array['DeliveryFee'] = 0;
					}

					if (($this->free_delivery == 'yes' ) && ($woocommerce->cart->cart_contents_total > $this->free_delivery_threshold)) {
						$cash_vault_post_array['RefundDelivery'] = 0;
						$cash_vault_post_array['DeliveryFee'] = 0;
					}

					$date1 = new DateTime();
					$wat_time = new DateTimeZone('Africa/Lagos');
					$date1->setTimezone($wat_time);

					$cash_vault_post_array['ReservationDate'] = $date1->format('Y-m-d H:i:s');
					if ($this->enabled_live == 'no') {
						$cash_vault_post_array['ReservationId'] = $this->test_api_merchant_id . time();
					} else {
						$cash_vault_post_array['ReservationId'] = $this->api_merchant_id . time();;
					}
					if ($this->split == 'yes') {
						if (($this->free_delivery == 'yes' ) && ($woocommerce->cart->cart_contents_total > $this->free_delivery_threshold)) {
							$tmp['AccountNo'] = $this->split_merchant_account;
							$tmp['CbnCode'] = $this->split_merchant_bank;
							$tmp['SplitPercentage'] = 100;
							$cash_vault_post_array['ReservationRequestSplits'][] = $tmp;
						} elseif ($this->split_courier == 'yes') {
							$tmp['AccountNo'] = $this->split_merchant_account;
							$tmp['CbnCode'] = $this->split_merchant_bank;

							if ($order_total > 100000) {
								$tmp['SplitPercentage'] = 100 - round(($courier['delivery_fee'] * 100 /($order_total - 2000)), 4);	
							} else {
								$tmp['SplitPercentage'] = 100 - round(($courier['delivery_fee'] * 98/($order_total)), 4);	
							}
							$cash_vault_post_array['ReservationRequestSplits'][] = $tmp;
							$tmp['AccountNo'] = $courier['account_number'];
							$tmp['CbnCode'] = $courier['bank'];
							if ($order_total > 100000) {
								$tmp['SplitPercentage'] = round($courier['delivery_fee'] * 100/($order_total - 2000), 4);
							} else {
								$tmp['SplitPercentage'] = round($courier['delivery_fee'] * 98/($order_total), 4);
							}
							$cash_vault_post_array['ReservationRequestSplits'][] = $tmp;
						} else {
							$tmp['AccountNo'] = $this->split_merchant_account;
							$tmp['CbnCode'] = $this->split_merchant_bank;
							$tmp['SplitPercentage'] = 100;
							$cash_vault_post_array['ReservationRequestSplits'][] = $tmp;
						}
					}
					$cash_vault_post_array['ReturnUrl'] = $this->get_return_url( $order );
				
				}
			    }
			    if ($dt == 0) {
					$details['status'] = 'error: Visitor did not select delivery type or non existent delivery type';
					update_cash_vaultdb($order_id, $details);
					wc_add_notice(  'Delivery Type Not Selected ', 'error' );
					return;			
			    }
			    if ($cash_vault_post_array['DeliveryFee'] > $cash_vault_post_array['OrderAmount']) {
					$details['status'] = 'error: Cancellation fee greater than order amount';
					update_cash_vaultdb($order_id, $details);
					wc_add_notice(  'Something went wrong ', 'error' );
					return;						
			    }
		}
		if ($this->enabled_live == 'no') {
			$headers = array("Content-type" => "application/json;charset=UTF-8", "ClientID" => $this->test_api_client_id, "ClientSecretKey" => $this->test_api_client_secret_key);
			$url = "https://staging.cashvaultng.com/plugin/reservation/";
		} else {
			$headers = array("Content-type" => "application/json;charset=UTF-8", "ClientID" => $this->api_client_id, "ClientSecretKey" => $this->api_client_secret_key);
			$url = "https://cashvaultng.com/app/reservation/";
		}

		$response = wp_remote_post( $url, array(
		    'method' => 'POST',
		    'timeout' => 45,
		    'redirection' => 5,
		    'httpversion' => '1.0',
		    'blocking' => true,
		    'headers' => $headers,
		    'body' => json_encode($cash_vault_post_array)
		    )
		);

		$response_array = json_decode(wp_remote_retrieve_body( $response ));
		$response_code = wp_remote_retrieve_response_code( $response );
		$response_message = wp_remote_retrieve_response_message( $response );


		$details['request'] = json_encode($cash_vault_post_array);
		$details['response_code'] = $response_code;
		$details['response_message'] = $response_message;
		$details['response_text'] =  wp_remote_retrieve_body( $response );

		if (200 == $response_code) {
			$details['ReservationId'] = $response_array->ReservationId;
			$details['status'] = 'reservation pending fund deposit';
		} else {
			wc_add_notice( json_encode($cash_vault_post_array) . "<BR>" . $details['response_text'] . "<BR>" . json_encode($response_array->Errors), 'error');
			return;

			if (isset($response_array['ResponseDescription'])) {
				$details['status'] = 'error: Reservation failed ' . json_encode($response_array->Errors);
			} else {
				$details['status'] = 'error: unknown error';
			}
		}

		update_cash_vaultdb($order_id, $details);

		if ( 200 != $response_code && ! empty( $response_message ) ) {
			wc_add_notice( $response_code . "--" . $response_message . "<BR> " . wp_remote_retrieve_body( $response ) . "<BR>" . json_encode($cash_vault_post_array) . "<BR>" . $cash_vault_post_array['ReturnUrl'] . "<BR>" . json_encode($headers) . "<BR>" . $url, 'error');
			return;
		} elseif ( 200 != $response_code ) {
			wc_add_notice( $response_code . " " . "Unknown error". "<BR>" . wp_remote_retrieve_body( $response ). "<BR>" . json_encode($cash_vault_post_array). "<BR>" . $cash_vault_post_array['ReturnUrl'] . "<BR>" . json_encode($headers) . "<BR>" . $url, 'error');
			return;
		} else {

	        }		

		if ( $order->get_total() > 0 ) {
			// Mark as Pending (we're awaiting the payment)
			$order->update_status( 'pending', __( 'Awaiting Secure of funds for payment', 'woocommerce' ) );
		} else {
			$order->payment_complete();
		}

		// Reduce stock levels
		wc_reduce_stock_levels( $order_id );

		// Remove cart
		WC()->cart->empty_cart();

		// Return thankyou redirect
		return array(
			'result'    => 'success',
			'redirect'  => $response_array->PaymentUrl,
		);

	}

	function action_woocommerce_cash_vaultreview_order_after_submit( ) {
		echo "review order after submit";
	}


	public function payment_fields() {
		$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
		$shipping = (Array) WC()->session->get( 'shipping_for_package_0' )['rates'][$chosen_methods[0]];
		$shipping_cost = $shipping["\0*\0" . "data"]["cost"];

		if ($this->enabled_live == 'no') {
			echo "TEST MODE ENABLED no real transaction will take place<BR>";
		}

		global $woocommerce;
		$amount = $woocommerce->cart->cart_contents_total;
		if (($this->free_delivery == 'yes' ) && ($woocommerce->cart->cart_contents_total > $this->free_delivery_threshold)) {
			if (strlen($chosen_methods[0]) <= 1) {
				echo "You are eligible for free delivery<BR>";
			}
		}
		if (strlen($chosen_methods[0]) <= 1) {
            ?>
            <script type="text/javascript">
				<?php  $admin_url = get_admin_url(); ?>
			jQuery(".myradio").on('click', function() { cash_vaultupdatecart();});
			jQuery('form.checkout').on('change', 'input[name=payment_method]', function() {cash_vaultupdatecart();});
  
			function cash_vaultupdatecart(){
                        
                        var data = {
                    		action: 'cash_vaultupdate_order_review',
                    		security: wc_checkout_params.update_order_review_nonce,
                    		post_data: jQuery( 'form.checkout' ).serialize()
                    	};
			
                    	jQuery.post( '<?php echo $admin_url; ?>' + 'admin-ajax.php', data, function( response )
                		{

                            jQuery( 'body' ).trigger( 'update_checkout' );
						});
                    	}
                </script>
             <?php  
        	$i = 0;
			echo "<BR>Choose a Delivery Type<BR>";
			foreach ($this->courier_details as $courier) {
				if (($this->free_delivery == 'yes' ) && ($woocommerce->cart->cart_contents_total > $this->free_delivery_threshold)) {
					echo "<input type=\"radio\" name=\"cash_vaultdelivery_type\"  class=\"myradio\" id=\"cash_vaultdelivery_type_$i\" value=\"".$courier['delivery_type']."\"> ".$courier['delivery_type'] . " - &#8358;0.00<BR>";
					$i++;
				} else {
					echo "<input type=\"radio\" name=\"cash_vaultdelivery_type\"  class=\"myradio\" id=\"cash_vaultdelivery_type_$i\" value=\"".$courier['delivery_type']."\"> ".$courier['delivery_type'] . " - &#8358;" . $courier['delivery_fee'] . "<BR>";
					$i++;
				}
			}
		} 
	}

        function cash_vaultupdate_order_review() {
		echo "cash_vaultupdate_order_review";
	    global $woocommerce;
        $values = array();
        parse_str(sanitize_text_field($_POST['post_data']), $values);
	    $this->delivery_type = '';
	    if (isset($values['payment_method'])) {
		 if ($values['payment_method'] == 'cash_vault' || $values['payment_method'] == 'cv') {
			    if (isset($values['cash_vaultdelivery_type'])) {
					$this->delivery_type =$values['cash_vaultdelivery_type'];
			    }
		}
	    }
	        WC()->session->set( 'cash_vaultdelivery_type', $this->delivery_type );
		//echo $this->delivery_type;
		//echo "\n".$this->test_api_merchant_id;
           exit;
        }
	
    } // end WC_Gateway_Cash_Vault


	function add_cash_vaultgateway_class( $methods ) {
	    $methods[] = 'WC_Gateway_Cash_Vault'; 
	    return $methods;
	}

	add_filter( 'woocommerce_payment_gateways', 'add_cash_vaultgateway_class' );
	$WC_Gateway_Cash_Vault = new WC_Gateway_Cash_Vault;
 }
} // end init_cash_vault_gateway_class

	//add_action( 'woocommerce_admin_order_data_after_shipping_address', 'action_woocommerce_admin_order_data_after_shipping_address', 10, 1 );
	add_action( 'woocommerce_admin_order_data_after_order_details', 'action_woocommerce_admin_order_data_after_order_details', 10, 1 );
    add_action( 'woocommerce_cart_calculate_fees', 'cash_vault_calculate_totals');
	add_action( 'woocommerce_thankyou', 'cash_vaultview_order_and_thankyou_page');
	add_action( 'woocommerce_view_order', 'cash_vaultview_order_and_thankyou_page');

	//function action_woocommerce_admin_order_data_after_shipping_address($order ) {
	//	echo $order->id . " order detail extra info";
	//}

	function action_woocommerce_admin_order_data_after_order_details($order ) {
		global $post;
		//echo  $order->id . " order detail extra info";
		echo "<BR>&nbsp;<BR>&nbsp;<BR>";
		get_cash_vaultstatus($order->id);
	}

	function cash_vaultview_order_and_thankyou_page($order_id) {
		//echo "this is order thank you page extra info " . $order_id;
		get_cash_vaultstatus($order_id);
	}

	function get_cash_vaultstatus($order_id) {
		global $wpdb, $table_name;
		cash_vault_table_create();
		$options = get_option('woocommerce_cash_vault_settings', array() );

		$order = wc_get_order( $order_id );
		$payment_method = $order->get_payment_method();

		if ($payment_method == 'cash_vault' || $payment_method == 'cv') {
			$sql = $wpdb->prepare("SELECT * FROM $table_name where `order_id` = %d AND `response_code` = %d", $order_id, "200");
			$result = $wpdb->get_results($sql);

			if ($result[0]->ReservationId != "") {
				if ($options['enabled_live'] == 'no') {
					$headers = array("Accept" => "application/json;charset=UTF-8", "ClientID" => $options['test_api_client_id'], "ClientSecretKey" => $options['test_api_client_secret_key']);
					$url = "https://api.cashvaultng.com/stagmerce/CVMerchantServices.svc/REST/GetReservationStatus?ReservationID=" . $result[0]->ReservationId;
				} elseif ($options['enabled_live'] == 'yes') {
					$headers = array("Accept" => "application/json;charset=UTF-8", "ClientID" => $options['api_client_id'], "ClientSecretKey" => $options['api_client_secret_key']);
					$url = "https://api.cashvaultng.com/cv3pt/CVMerchantServices.svc/REST/GetReservationStatus?ReservationID=" . $result[0]->ReservationId;
				}
				$args = Array('headers' => $headers);
				$response = wp_remote_get( $url, $args);
				$status_response_array = json_decode(wp_remote_retrieve_body( $response ));
				
				if ($status_response_array->ResponseCode == '00') {
					echo "<h2 class=\"woocommerce-order-details__title\">Cashvault Payment Status</h2>\n";
					echo "<ul class=\"woocommerce-order-overview woocommerce-thankyou-order-details order_details\">\n";
					echo "<li class=\"woocommerce-order-overview__order order\">";
					if (is_null($status_response_array->FundSecuredDate)) {
						$order->update_status( 'pending', __( 'Awaiting Secure of funds for payment', 'woocommerce' ) );
						echo "<font color=red><strong>Fund not Secured.</strong><BR></font>";
						echo "Status: <strong>Fund Not Secured</strong><BR>";
					} else {
						if ($status_response_array->DurationRemaining == '00:00:00') {
							if ($status_response_array->VaultCodeStatus == '0') {
								$order->update_status( 'cancelled', __( 'Fund Expired', 'woocommerce' ) );
								echo "Status: <strong>Secured Fund Reversed - Unsuccessful Delivery</strong><BR>";
								$details['status'] = "Secured Fund Reversed";
							} elseif ($status_response_array->VaultCodeStatus == '1') {
								$order->update_status( 'completed', __( 'Delivered', 'woocommerce' ) );
								echo "Status: <strong> Secured Fund Redeemed - Successful Delivery</strong><BR>";
								$details['status'] = "Secured Fund Redeemed";
							}
						} else {
							$order->update_status( 'processing', __( 'Fund Secured Pending Delivery', 'woocommerce' ) );
							echo "<font color=green><BR>Fund Secured on ". $status_response_array->FundSecuredDate ."<BR></font>";
							echo "Status: <strong>Fund Secured Pending Delivery</strong><BR>";
							$details['status'] = "Fund Secured Pending Delivery";
						}
					}
					echo "</li>";		
					echo "</ul>";

				}
				echo "<BR>";
				$status_response_code = wp_remote_retrieve_response_code( $response );
				$status_response_message = wp_remote_retrieve_response_message( $response );

				$details['status_response_code'] = $status_response_code;
				$details['status_response_message'] = $status_response_message;
				$details['status_response_text'] =  wp_remote_retrieve_body( $response );
				$sql = $wpdb->prepare("UPDATE `$table_name` set `status`=%s,`status_response_code`=%s,`status_response_text`=%s WHERE id=%s", $details['status'], $details['status_response_code'], $details['status_response_text'],$result[0]->id);
				$wpdb->query($sql);
			}
		}
		
	}

	function update_cash_vaultdb($order_id, $details) {
		global $wpdb, $table_name;
		cash_vault_table_create();
		$request = isset($details['request']) ? $details['request'] : "";
		$response_text = isset($details['response_text']) ? $details['response_text'] : "";
		$response_code = isset($details['response_code']) ? $details['response_code'] : "";
		$response_message = isset($details['response_message']) ? $details['response_message'] : "";
		$ReservationId = isset($details['ReservationId']) ? $details['ReservationId'] : "";
		$status = isset($details['status']) ? $details['status'] : "";
		$status_response_text = isset($details['status_response_text']) ? $details['status_response_text'] : "";
		$status_response_code = isset($details['status_response_code']) ? $details['status_response_code'] : "";
		$status_response_message = isset($details['status_response_message']) ? $details['status_response_message'] : "";
		$sql = $wpdb->prepare("INSERT INTO `$table_name` (`order_id`, `request`, `response_text`, `response_code`, `response_message`, `ReservationId`, `status`, `status_response_text`, `status_response_code`, `status_response_message`) VALUES 
			( %d, %s, %s, %s, %s, %s, %s, %s, %s, %s);",
			$order_id,
			$request,
			$response_text,
			$response_code,
			$response_message,
			$ReservationId,
			$status,
			$status_response_text,
			$status_response_code,
			$status_response_message
			);
		$wpdb->query($sql);
	}
	function cash_vault_calculate_totals( $totals ) {
		//echo "<script>console.log(\"calculate_totals\");</script>";
		//print_r($totals);
		return $totals;
	}

	function cash_vault_table_create() {
		global $wpdb, $table_name;

		if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
		     //table not in database. Create new table
		     $charset_collate = $wpdb->get_charset_collate();
 
 		    $sql = "CREATE TABLE $table_name (
		          id mediumint(9) NOT NULL AUTO_INCREMENT,
		          order_id mediumint(9) NOT NULL,
		          request text NOT NULL,
		          response_text text NOT NULL,
		          response_code int NOT NULL,
		          response_message varchar(255) NOT NULL,
			  ReservationId varchar(20) NOT NULL,
			  status varchar(255) NOT NULL,
		          status_response_text text NOT NULL,
		          status_response_code int NOT NULL,
		          status_response_message varchar(255) NOT NULL,
		          UNIQUE KEY id (id)
		     ) $charset_collate;";
		     require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		     dbDelta( $sql );
		}
	}

?>